#
# spec file for package spacewalk-oscap
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008-2018 Red Hat, Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?fedora} || 0%{?suse_version} > 1320 || 0%{?rhel} >= 8
%global build_py3   1
%global default_py3 1
%endif

%if ( 0%{?fedora} && 0%{?fedora} < 28 ) || ( 0%{?rhel} && 0%{?rhel} < 8 ) || 0%{?suse_version}
%global build_py2   1
%endif

%define pythonX %{?default_py3: python3}%{!?default_py3: python2}

Name:           spacewalk-oscap
Version:        4.2.2
Release:    3.12.1
Summary:        OpenSCAP plug-in for rhn-check
License:        GPL-2.0-only
Group:          Applications/System

Url:            https://github.com/uyuni-project/uyuni
Source0: spacewalk-oscap-git-0.81ddb22.tar.gz
Source1:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora} || 0%{?rhel} || 0%{?suse_version} >= 1210
BuildArch:      noarch
%endif
BuildRequires:  libxslt
%if ( 0%{?rhel} && 0%{?rhel} < 8 ) || 0%{?suse_version}
Requires:       openscap-utils
%else
Requires:       openscap-scanner
%endif
Requires:       %{pythonX}-%{name} = %{version}-%{release}
Requires:       libxslt

%description
spacewalk-oscap is a plug-in for rhn-check. With this plugin, user is able
to run OpenSCAP scan from Spacewalk or Red Hat Satellite server.

%if 0%{?build_py2}
%package -n python2-%{name}
Summary:        OpenSCAP plug-in for rhn-check
Group:          Applications/System
Provides:       python-%{name} = %{version}-%{release}
Obsoletes:      python-%{name} < %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Requires:       python2-rhn-check >= 2.8.4
Requires:       rhnlib >= 2.8.3
BuildRequires:  python-devel
BuildRequires:  rhnlib >= 2.8.3

%description -n python2-%{name}
Python 2 specific files for %{name}.
%endif

%if 0%{?build_py3}
%package -n python3-%{name}
Summary:        OpenSCAP plug-in for rhn-check
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}
Requires:       python3-rhn-check >= 2.8.4
Requires:       python3-rhnlib >= 2.8.3
BuildRequires:  python3-devel
BuildRequires:  python3-rhnlib >= 2.8.3

%description -n python3-%{name}
Python 3 specific files for %{name}.
%endif

%prep
%setup -q -n spacewalk-oscap-git-0.81ddb22

%build
make -f Makefile.spacewalk-oscap

%install
%if 0%{?build_py2}
make -f Makefile.spacewalk-oscap install PREFIX=$RPM_BUILD_ROOT PYTHONPATH=%{python_sitelib}
%endif
%if 0%{?build_py3}
make -f Makefile.spacewalk-oscap install PREFIX=$RPM_BUILD_ROOT PYTHONPATH=%{python3_sitelib}
%endif

%if 0%{?suse_version}
%if 0%{?build_py2}
%py_compile -O %{buildroot}/%{python_sitelib}
%endif
%if 0%{?build_py3}
%py3_compile -O %{buildroot}/%{python3_sitelib}
%endif
%endif

%files
%defattr(-,root,root)
%doc COPYING
%config  /etc/sysconfig/rhn/clientCaps.d/scap
%{_datadir}/openscap/xsl/xccdf-resume.xslt
%if 0%{?suse_version}
%dir /etc/sysconfig/rhn
%dir /etc/sysconfig/rhn/clientCaps.d
%dir %{_datadir}/openscap
%dir %{_datadir}/openscap/xsl
%endif

%if 0%{?build_py2}
%files -n python2-%{name}
%defattr(-,root,root)
%dir %{python_sitelib}/rhn/actions
%{python_sitelib}/rhn/actions/scap.*
%if 0%{?suse_version}
%dir %{python_sitelib}/rhn/actions
%endif
%endif

%if 0%{?build_py3}
%files -n python3-%{name}
%defattr(-,root,root)
%{python3_sitelib}/rhn/actions/scap.*
%{python3_sitelib}/rhn/actions/__pycache__/scap.*
%if 0%{?suse_version}
%dir %{python3_sitelib}/rhn/actions
%dir %{python3_sitelib}/rhn/actions/__pycache__
%endif
%endif

%changelog
* Fri Jul 16 2021 jgonzalez@suse.com
- version 4.2.2-1
- Adapt the tests to the new images
* Fri Sep 18 2020 jgonzalez@suse.com
- version 4.2.1-1
- Update package version to 4.2.0
* Wed Nov 27 2019 jgonzalez@suse.com
- version 4.1.1-1
- Bump version to 4.1.0 (bsc#1154940)
* Wed May 15 2019 jgonzalez@suse.com
- version 4.0.5-1
- SPEC cleanup
* Mon Apr 22 2019 jgonzalez@suse.com
- version 4.0.4-1
- add makefile and pylint configuration
* Mon Dec 17 2018 jgonzalez@suse.com
- version 4.0.3-1
- Fix python2 compilation on openSUSE
* Fri Oct 26 2018 jgonzalez@suse.com
- version 4.0.2-1
- Add Uyuni URL to package
* Fri Aug 10 2018 jgonzalez@suse.com
- version 4.0.1-1
- Bump version to 4.0.0 (bsc#1104034)
- Fix copyright for the package specfile (bsc#1103696)
* Wed May 16 2018 jgonzalez@suse.com
- version 2.8.8.2-1
- Require openscap-scanner on newer versions of RHEL (bsc#1093545)
* Mon Mar 26 2018 jgonzalez@suse.com
- version 2.8.8.1-1
- Sync with upstream (bsc#1083294)
- Build python2 packages on SUSE systems
* Mon Mar  5 2018 jgonzalez@suse.com
- version 2.8.7.2-1
- remove clean section from spec (bsc#1083294)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 2.8.7.1-1
- Sync with upstream
* Fri Nov 10 2017 mc@suse.de
- version 2.8.4.1-1
- add missing directories to filelist
* Thu Oct 26 2017 mc@suse.de
- version 2.8.3.1-1
- split spacewalk-oscap into python2/python3 specific packages
- Support xccdf 1.2 namespace in openscap result file (bsc#1059319)
* Tue May 23 2017 mc@suse.de
- version 2.7.0.3-1
- require openscap-utils on rhel for backward compatibility
* Mon Mar  6 2017 mc@suse.de
- version 2.7.0.2-1
- Updated links to github in spec files
* Wed Jan 11 2017 michele.bologna@suse.com
- version 2.7.0.1-1
- Bumping package versions for 2.7.
* Tue Jan 26 2016 mc@suse.de
- version 2.5.1.1-1
- still require openscap-utils on RHEL5
* Wed Oct  7 2015 mc@suse.de
- version 2.5.0.1-1
- Bumping package versions for 2.5.
* Tue Oct 14 2014 mc@suse.de
- version 0.0.23.4-1
- Avoid creating profile with empty id
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Thu Apr 10 2014 mc@suse.de
- version 0.0.23.3-1
* Thu Apr 10 2014 mc@suse.de
- fix release in specfile for SLE12 (bnc#872970)
* Mon Feb 17 2014 mc@suse.de
- version 0.0.23.2-1
- add COPYING file
* Fri Feb  7 2014 mc@suse.de
- version 0.0.23.1-1
- Add tailoring support to the Spacewalk (OpenSCAP enabled) client
* Mon Dec  9 2013 mc@suse.de
- version 0.0.22.1-1
- switch to 2.1
* Mon Jul 16 2012 ug@suse.de
- version 0.0.4.6-1
- Fix spacewalk-oscap typos
* Thu Jun 21 2012 jrenner@suse.de
- version 0.0.4.5-1
- Forbid oscap args other than --profile and --skip-valid
* Wed May  2 2012 mc@suse.de
- version 0.0.4.4-1
- Do not pass empty string as parameter to oscap tool.
* Fri Apr 27 2012 mc@suse.de
- version 0.0.4.3-1
- Spacewalk-oscap requires oscap tool of particular version.
* Fri Apr 20 2012 mc@suse.de
- version 0.0.4.2-1
- When errors occur submit them back to the server.
- Store also @idref of xccdf:rule-result element
- We want to store all idents per rule-result
- Only one Profile element is useful
- Make sure only one TestResult element is used
* Wed Mar 21 2012 mc@suse.de
- version 0.0.4.1-1
- Bumping package version
* Wed Feb 29 2012 mc@suse.de
- initial package release
